import {Autocomplete, Box, TextField} from '@mui/material'
import {Edit, useAutocomplete} from '@refinedev/mui'
import {useForm} from '@refinedev/react-hook-form'
import {Controller} from 'react-hook-form'

export const CityEdit = () => {
  const {
    saveButtonProps,
    register,
    control,
    formState: {errors},
  } = useForm({})

  const {autocompleteProps: countryAutocompleteProps} = useAutocomplete({
    resource: 'country',
  })

  const {autocompleteProps: mediaAutocompleteProps} = useAutocomplete({
    resource: 'media',
    onSearch: (value) => [
      {
        field: 'media_name',
        operator: 'contains',
        value,
      },
    ],
  })

  return (
    <Edit saveButtonProps={saveButtonProps}>
      <Box component="form" sx={{display: 'flex', flexDirection: 'column'}} autoComplete="off">
        <Controller
          control={control}
          name="country_code"
          rules={{required: 'Это поле является обязательным'}}
          defaultValue={null}
          render={({field}) => (
            <Autocomplete
              {...countryAutocompleteProps}
              value={countryAutocompleteProps.options.find((option) => option.code === field.value) || null}
              onChange={(_, value) => {
                field.onChange(value?.code || '')
              }}
              getOptionLabel={(item) => {
                return item ? item.name : ''
              }}
              isOptionEqualToValue={(option, value) => {
                return option.id === value?.id
              }}
              renderInput={(params) => <TextField {...params} label="Выберите страну" margin="normal" variant="outlined" error={!!errors.country_code} helperText={(errors as any)?.country_code?.message} required />}
            />
          )}
        />

        <TextField
          {...register('name', {
            required: 'Это поле является обязательным',
          })}
          error={!!(errors as any)?.title}
          helperText={(errors as any)?.title?.message}
          margin="normal"
          fullWidth
          InputLabelProps={{shrink: true}}
          type="text"
          label={'Название *'}
          name="name"
        />

        <Controller
          control={control}
          name="arms"
          // rules={{required: 'Это поле является обязательным'}}
          defaultValue={null}
          render={({field}) => (
            <Autocomplete
              {...mediaAutocompleteProps}
              value={mediaAutocompleteProps.options.find((option) => option.id === field.value) || null}
              onChange={(_, value) => {
                field.onChange(value?.id || '')
              }}
              getOptionLabel={(item) => {
                return item ? item.media_name : ''
              }}
              isOptionEqualToValue={(option, value) => {
                return option.id === value?.id
              }}
              filterOptions={(options, {inputValue}) => {
                return options.filter((option) => option.media_name.toLowerCase().includes(inputValue.toLowerCase()))
              }}
              renderInput={(params) => <TextField {...params} label="Выберите герб" margin="normal" variant="outlined" error={!!errors.arms} helperText={(errors as any)?.arms?.message} />}
            />
          )}
        />
      </Box>
    </Edit>
  )
}
