import { RefObject, useMemo } from 'react';
export function useCssProperty<T>(
  propName: string,
  elementRef: RefObject<HTMLElement>,
  setFormatter: (value: T) => string = (val) => `${val}`,
  getFormatter: (strVal: string | null) => T = (strVal) => strVal as T
): { value: T | null } {
  return useMemo(
    () => ({
      get value() {
        const rawValue = elementRef?.current?.style.getPropertyValue(propName) ?? null;

        return getFormatter(rawValue);
      },

      set value(val) {
        elementRef?.current?.style.setProperty(propName, setFormatter(val));
      },
    }),
    [propName, elementRef, getFormatter, setFormatter]
  );
}
